"""This submodule contains basic information about the package.
"""

#! TODO: Add functions to print the help message. This package is intended to be compatible with command-line interfaces. To be more precise, function docstrings should be called when the user types `pyovo --help` or `pyovo -h`.

def version():
    print("This is the version function.\n")
    print("Returning the version number: 0.0.2\n")
    return 0
